Documentation
¶
Index ¶
- type BuildInfo
- type GitHubAuthDemo
- type Node
- type Option
- func WithConfigFileChange(event chan struct{}) Option
- func WithDebugMode(enable bool) Option
- func WithDevMode() Option
- func WithFileSystemConfig(configFilePath string) Option
- func WithForceHttpsRedirects(forceHttpsRedirects bool) Option
- func WithGitHubAuthDemo(authDemo GitHubAuthDemo) Option
- func WithGlobalRateLimit(requests int, perDuration time.Duration) Option
- func WithInsecureCookies() Option
- func WithIntrospection(enable bool) Option
- func WithStaticWunderNodeConfig(config WunderNodeConfig) Option
- type Server
- type WunderNodeConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GitHubAuthDemo ¶
type Node ¶
type Node struct {
// contains filtered or unexported fields
}
func (*Node) HandleGracefulShutdown ¶ added in v0.110.0
func (*Node) StartBlocking ¶
type Option ¶
type Option func(options *options)
func WithConfigFileChange ¶ added in v0.91.0
func WithConfigFileChange(event chan struct{}) Option
func WithDebugMode ¶
func WithDevMode ¶ added in v0.102.0
func WithDevMode() Option
WithDevMode will set cookie secrets to a static, insecure, string This way, you stay logged in during development Should never be used in production
func WithFileSystemConfig ¶
func WithForceHttpsRedirects ¶
func WithGitHubAuthDemo ¶
func WithGitHubAuthDemo(authDemo GitHubAuthDemo) Option
func WithInsecureCookies ¶
func WithInsecureCookies() Option
func WithIntrospection ¶
func WithStaticWunderNodeConfig ¶
func WithStaticWunderNodeConfig(config WunderNodeConfig) Option
type WunderNodeConfig ¶ added in v0.110.0
type WunderNodeConfig struct {
Server *Server
Api *apihandler.Api
}
func CreateConfig ¶ added in v0.110.0
func CreateConfig(graphConfig *wgpb.WunderGraphConfiguration) WunderNodeConfig
Click to show internal directories.
Click to hide internal directories.